[PATCH V2 02/19] bus: omap_l3_noc: rename functions and data to omap_l3

2014-04-17 Thread Nishanth Menon
From: Sricharan R r.sricha...@ti.com

Since omap_l3_noc driver is now being used for OMAP5 and reusable with
DRA7 and AM437x, using omap4 specific naming is misleading.

Signed-off-by: Sricharan R r.sricha...@ti.com
Signed-off-by: Nishanth Menon n...@ti.com
---

V2: reordered the patch
V1: https://patchwork.kernel.org/patch/3984321/

 drivers/bus/omap_l3_noc.c |   24 
 drivers/bus/omap_l3_noc.h |   11 ++-
 2 files changed, 18 insertions(+), 17 deletions(-)

diff --git a/drivers/bus/omap_l3_noc.c b/drivers/bus/omap_l3_noc.c
index 1eb6d85..800486c 100644
--- a/drivers/bus/omap_l3_noc.c
+++ b/drivers/bus/omap_l3_noc.c
@@ -1,5 +1,5 @@
 /*
  * OMAP4XXX L3 Interconnect error handling driver
  *
  * Copyright (C) 2011-2014 Texas Instruments Incorporated - http://www.ti.com/
  * Santosh Shilimkar santosh.shilim...@ti.com
@@ -50,7 +50,7 @@
 static irqreturn_t l3_interrupt_handler(int irq, void *_l3)
 {
 
-   struct omap4_l3 *l3 = _l3;
+   struct omap_l3 *l3 = _l3;
int inttype, i, k;
int err_src = 0;
u32 std_err_main, err_reg, clear, masterid;
@@ -122,9 +122,9 @@ static irqreturn_t l3_interrupt_handler(int irq, void *_l3)
return IRQ_HANDLED;
 }
 
-static int omap4_l3_probe(struct platform_device *pdev)
+static int omap_l3_probe(struct platform_device *pdev)
 {
-   static struct omap4_l3 *l3;
+   static struct omap_l3 *l3;
int ret, i;
 
l3 = devm_kzalloc(pdev-dev, sizeof(*l3), GFP_KERNEL);
@@ -176,8 +176,8 @@ MODULE_DEVICE_TABLE(of, l3_noc_match);
 #define l3_noc_match NULL
 #endif
 
-static struct platform_driver omap4_l3_driver = {
-   .probe  = omap4_l3_probe,
+static struct platform_driver omap_l3_driver = {
+   .probe  = omap_l3_probe,
.driver = {
.name   = omap_l3_noc,
.owner  = THIS_MODULE,
@@ -185,14 +185,14 @@ static struct platform_driver omap4_l3_driver = {
},
 };
 
-static int __init omap4_l3_init(void)
+static int __init omap_l3_init(void)
 {
-   return platform_driver_register(omap4_l3_driver);
+   return platform_driver_register(omap_l3_driver);
 }
-postcore_initcall_sync(omap4_l3_init);
+postcore_initcall_sync(omap_l3_init);
 
-static void __exit omap4_l3_exit(void)
+static void __exit omap_l3_exit(void)
 {
-   platform_driver_unregister(omap4_l3_driver);
+   platform_driver_unregister(omap_l3_driver);
 }
-module_exit(omap4_l3_exit);
+module_exit(omap_l3_exit);
@@ -1,5 +1,5 @@
 /*
- * OMAP4XXX L3 Interconnect error handling driver
+ * OMAP L3 Interconnect error handling driver
  *
  * Copyright (C) 2011-2014 Texas Instruments Incorporated - http://www.ti.com/
diff --git a/drivers/bus/omap_l3_noc.h b/drivers/bus/omap_l3_noc.h
index cc4b1b1..b3c81f2 100644
--- a/drivers/bus/omap_l3_noc.h
+++ b/drivers/bus/omap_l3_noc.h
@@ -1,5 +1,5 @@
 /*
  * OMAP4XXX L3 Interconnect  error handling driver header
  *
  * Copyright (C) 2011-2014 Texas Instruments Incorporated - http://www.ti.com/
  * Santosh Shilimkar santosh.shilim...@ti.com
@@ -14,8 +14,8 @@
  * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  */
-#ifndef __ARCH_ARM_MACH_OMAP2_L3_INTERCONNECT_3XXX_H
-#define __ARCH_ARM_MACH_OMAP2_L3_INTERCONNECT_3XXX_H
+#ifndef __OMAP_L3_NOC_H
+#define __OMAP_L3_NOC_H
 
 #define L3_MODULES 3
 #define CLEAR_STDERR_LOG   (1  31)
@@ -157,7 +157,7 @@ static u32 *l3_targ[L3_MODULES] = {
l3_targ_inst_clk3,
 };
 
-struct omap4_l3 {
+struct omap_l3 {
struct device *dev;
struct clk *ick;
 
@@ -167,4 +167,5 @@ struct omap4_l3 {
int debug_irq;
int app_irq;
 };
-#endif
+
+#endif /* __OMAP_L3_NOC_H */
@@ -1,5 +1,5 @@
 /*
- * OMAP4XXX L3 Interconnect  error handling driver header
+ * OMAP L3 Interconnect  error handling driver header
  *
  * Copyright (C) 2011-2014 Texas Instruments Incorporated - http://www.ti.com/
-- 
1.7.9.5

--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


Re: [PATCH V2 02/19] bus: omap_l3_noc: rename functions and data to omap_l3

2014-04-17 Thread Santosh Shilimkar
On Thursday 17 April 2014 04:49 PM, Nishanth Menon wrote:
 From: Sricharan R r.sricha...@ti.com
 
 Since omap_l3_noc driver is now being used for OMAP5 and reusable with
 DRA7 and AM437x, using omap4 specific naming is misleading.
 
 Signed-off-by: Sricharan R r.sricha...@ti.com
 Signed-off-by: Nishanth Menon n...@ti.com
 ---
 
Acked-by: Santosh Shilimkar santosh.shilim...@ti.com

--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html